@@ -23,9 +23,10 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.c,v 1.92.2.5 2004/06/13 22:55:27 fuyu Exp $
+ * $Id: boardlist_ui.c,v 1.92.2.8 2004/11/13 12:40:52 fuyu Exp $
  */
 
+#define _BOARDLIST_UI_C_ 1
 #include "config.h"
 
 #include "ochusha_private.h"
@@ -184,7 +185,6 @@ static pthread_mutex_t board_list_lock;
 
 
 static GQuark category_gui_info_id;
-static GQuark application_id;
 
 
 void
@@ -198,8 +198,6 @@ prepare_boardlist_ui_initialization(OchushaApplication *application)
 
   category_gui_info_id
     = g_quark_from_static_string("BoardlistUI::CategoryInfo");
-  application_id
-    = g_quark_from_static_string("BoardlistUI::Application");
 }
 
 
@@ -2141,8 +2139,8 @@ new_thread_dialog_response_cb(GtkWidget *dialog, int response_id,
 {
   OchushaBulletinBoard *board = g_object_get_data(G_OBJECT(dialog), "board");
   gboolean result;
-  guint message_id = (guint)g_object_get_data(G_OBJECT(dialog),
-					      "statusbar_message");
+  guint message_id = (guint)(long)g_object_get_data(G_OBJECT(dialog),
+						    "statusbar_message");
 
   if (response_id == GTK_RESPONSE_REJECT)
     {
@@ -2240,7 +2238,7 @@ new_thread_dialog_response_cb(GtkWidget *dialog, int response_id,
 					      new_thread_netstat_id,
 					      statusbar_message);
 	      g_object_set_data(G_OBJECT(dialog), "statusbar_message",
-				(gpointer)message_id);
+				(gpointer)(long)message_id);
 	    }
 	}
       else
@@ -2371,6 +2369,10 @@ create_new_thread_dialog(OchushaApplication *application,
 
   gtk_widget_show(editor);
 
+#if GTK_MINOR_VERSION > 2
+  setup_aalist(application, response_editor);
+#endif
+
   gtk_box_pack_start(GTK_BOX(dialog_vbox), editor, TRUE, TRUE, 0);
 
   g_object_set_data(G_OBJECT(new_thread_dialog), "editor", editor);
