@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: regex_utils.c,v 1.7 2004/03/21 21:35:11 fuyu Exp $
+ * $Id: regex_utils.c,v 1.7.2.1 2004/11/25 09:00:58 fuyu Exp $
  */
 
 #include "config.h"
@@ -41,8 +41,8 @@
 # include <oniguruma.h>
 #endif
 
-#if (ONIGURUMA_VERSION_MAJOR >= 2) && (ONIGURUMA_VERSION_MINOR > 0)
-# define ONIGURUMA_2_2_API		1
+#if (ONIGURUMA_VERSION_MAJOR < 2) || (ONIGURUMA_VERSION_MINOR < 2)
+#error "Please use included oniguruma, we no longer support oniguruma prior to 2.2"
 #endif
 
 #include <stdio.h>
@@ -138,11 +138,7 @@ regex_editor_finalize(GObject *object)
 
   if (editor->expression != NULL)
     {
-#ifdef ONIGURUMA_2_2_API
       onig_free((regex_t *)editor->expression);
-#else
-      regex_free((regex_t *)editor->expression);
-#endif
       editor->expression = NULL;
     }
   if (editor->regex_buffer != NULL)
@@ -193,19 +189,9 @@ regex_editor_synthesize_regular_expression(const gchar *text)
       if (tmp_pos == end_pos)
 	goto next_line;
 
-#ifdef ONIGURUMA_2_2_API
-      if (onig_new(&regex, tmp_pos, end_pos, ONIG_OPTION_EXTEND,
+      if (onig_new(&regex, tmp_pos, end_pos, ONIG_OPTION_NONE,
 		   ONIG_ENCODING_UTF8,
-		   ONIG_SYNTAX_POSIX_EXTENDED, NULL) == ONIG_NORMAL)
-#else
-      if (regex_new(&regex, tmp_pos, end_pos, REG_OPTION_EXTEND,
-# ifdef REG_ENCODING_UTF8
-		    REG_ENCODING_UTF8,
-# else /* old style */
-		    REGCODE_UTF8,
-# endif
-		    REG_SYNTAX_POSIX_EXTENDED, NULL) == REG_NORMAL)
-#endif
+		   ONIG_SYNTAX_RUBY, NULL) == ONIG_NORMAL)
 	{
 	  gchar *sub_exp = G_STRNDUP(tmp_pos, end_pos - tmp_pos + 1);
 	  if (result == NULL)
@@ -220,11 +206,7 @@ regex_editor_synthesize_regular_expression(const gchar *text)
 	    }
 	}
 
-#ifdef ONIGURUMA_2_2_API
       onig_free(regex);
-#else
-      regex_free(regex);
-#endif
 
     next_line:
       tmp_pos = end_pos + 1;
@@ -329,17 +311,12 @@ gpointer
 oniguruma_regex_new(const gchar *pattern, const char *encoding)
 {
   regex_t *result;
-#ifdef ONIGURUMA_2_2_API
   OnigEncoding code;
-#else
-  RegCharEncoding code;
-#endif
 
   g_return_val_if_fail(pattern != NULL && *pattern != '\0', NULL);
 
   if (encoding != NULL)
     {
-#ifdef ONIGURUMA_2_2_API
       if (strcmp(encoding, "CP932") == 0)
 	code = ONIG_ENCODING_SJIS;
       else if (strcmp(encoding, "EUC-JP") == 0)
@@ -353,57 +330,15 @@ oniguruma_regex_new(const gchar *pattern, const char *encoding)
     }
   else
     code = ONIG_ENCODING_UTF8;
-#else
-# ifdef REG_ENCODING_UNDEF
-      if (strcmp(encoding, "CP932") == 0)
-	code = REG_ENCODING_SJIS;
-      else if (strcmp(encoding, "EUC-JP") == 0)
-	code = REG_ENCODING_EUC_JP;
-      else if (strcmp(encoding, "UTF-8") == 0)
-	code = REG_ENCODING_UTF8;
-      else if (strcmp(encoding, "Shift_JIS") == 0)
-	code = REG_ENCODING_SJIS;
-      else
-	code = REG_ENCODING_UTF8;
-    }
-  else
-    code = REG_ENCODING_UTF8;
-# else /* old style */
-      if (strcmp(encoding, "CP932") == 0)
-	code = REGCODE_SJIS;
-      else if (strcmp(encoding, "EUC-JP") == 0)
-	code = REGCODE_EUCJP;
-      else if (strcmp(encoding, "UTF-8") == 0)
-	code = REGCODE_UTF8;
-      else if (strcmp(encoding, "Shift_JIS") == 0)
-	code = REGCODE_SJIS;
-      else
-	code = REGCODE_UTF8;
-    }
-  else
-    code = REGCODE_UTF8;
-# endif
-#endif
 
-#ifdef ONIGURUMA_2_2_API
   if (onig_new(&result, (UChar *)pattern, (UChar *)pattern + strlen(pattern),
-	       ONIG_OPTION_EXTEND, code,
-	       ONIG_SYNTAX_POSIX_EXTENDED, NULL) != ONIG_NORMAL)
+	       ONIG_OPTION_NONE, code,
+	       ONIG_SYNTAX_RUBY, NULL) != ONIG_NORMAL)
     {
       onig_free(result);
       fprintf(stderr, "Invalid regular expression: \"%s\"\n", pattern);
       return NULL;
     }
-#else
-  if (regex_new(&result, (UChar *)pattern, (UChar *)pattern + strlen(pattern),
-		REG_OPTION_EXTEND, code,
-		REG_SYNTAX_POSIX_EXTENDED, NULL) != REG_NORMAL)
-    {
-      regex_free(result);
-      fprintf(stderr, "Invalid regular expression: \"%s\"\n", pattern);
-      return NULL;
-    }
-#endif
 
   return result;
 }
@@ -414,11 +349,7 @@ oniguruma_regex_free(gpointer oniguruma_regex)
 {
   g_return_if_fail(oniguruma_regex != NULL);
 
-#ifdef ONIGURUMA_2_2_API
   onig_free((regex_t *)oniguruma_regex);
-#else
-  regex_free((regex_t *)oniguruma_regex);
-#endif
 }
 
 
@@ -432,13 +363,7 @@ oniguruma_regex_match(gpointer oniguruma_regex, const char *text)
 
   text_end = (UChar *)text + strlen(text);
 
-#ifdef ONIGURUMA_2_2_API
   return onig_search((regex_t *)oniguruma_regex,
 		     (UChar *)text, text_end,
 		     (UChar *)text, text_end, NULL, 0) >= 0;
-#else
-  return regex_search((regex_t *)oniguruma_regex,
-		      (UChar *)text, text_end,
-		      (UChar *)text, text_end, NULL, 0) >= 0;
-#endif
 }
