@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_view.h,v 1.36.2.2 2004/06/14 10:28:39 fuyu Exp $
+ * $Id: threadlist_view.h,v 1.36.2.3 2004/12/29 07:25:34 fuyu Exp $
  */
 
 #ifndef _THREADLIST_VIEW_H_
@@ -182,6 +182,10 @@ struct _ThreadlistViewClass
 		      OchushaBBSThread *thread);
   void (*copy_thread_url)(ThreadlistView *threadlist_view,
 			  OchushaBBSThread *thread);
+  void (*copy_thread_title)(ThreadlistView *threadlist_view,
+			    OchushaBBSThread *thread);
+  void (*copy_thread_title_url)(ThreadlistView *threadlist_view,
+				OchushaBBSThread *thread);
   gboolean (*advance_view)(ThreadlistView *threadlist_view,
 			   OchushaBBSThread *thread);
   gboolean (*back_view)(ThreadlistView *threadlist_view,
