@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: htmlutils.c,v 1.14 2004/02/27 23:25:34 fuyu Exp $
+ * $Id: htmlutils.c,v 1.14.2.2 2004/11/25 08:57:33 fuyu Exp $
  */
 
 #include "config.h"
@@ -314,6 +314,7 @@ static const gchar * const default_entity[] =
     "amp", "&",
     "lt", "<",
     "gt", ">",
+    "apos", "'",		/* ? */
 
     "OElig", "\305\222",	/* U+0152 000 101 - 010 010 */
     "oelig", "\305\223",	/* U+0153 */
@@ -401,7 +402,7 @@ default_entity_ref_handler(ElementHandler *handler, void *context,
 
   len = strlen(entity);
 
-  if (entity[0] == '#' && len > 3)
+  if (entity[0] == '#' && len >= 2)
     {
       unsigned int character;
       int result;
@@ -547,7 +548,8 @@ parse_text_internal(ElementHandler *handler, void *context, const char *text,
 #if ENABLE_MS_IZONMOJI
 		  do
 		    {
-		      size = iconv(handler->converter, &inbuf, &inbytesleft,
+		      size = iconv(handler->converter,
+				   (ICONV_CONST char **)&inbuf, &inbytesleft,
 				   &outbuf, &outbytesleft);
 		      if (size == -1 && errno == EILSEQ
 			  && handler->helper != NULL)
@@ -606,7 +608,8 @@ parse_text_internal(ElementHandler *handler, void *context, const char *text,
 		    }
 #else
 		  size = iconv(handler->converter,
-			       &inbuf, &inbytesleft, &outbuf, &outbytesleft);
+			       (ICONV_CONST char **)&inbuf, &inbytesleft,
+			       &outbuf, &outbytesleft);
 		  if (size == -1)
 		    {
 		      if (errno == E2BIG)
@@ -1143,8 +1146,7 @@ fake_anchor_tag(ElementHandler *handler, void *context, const char *head,
   if (handler->startElement != NULL)
     (*handler->startElement)(context, "a", (const char *const *)attrs);
 
-  if (handler->characters != NULL)
-    (*handler->characters)(context, head, tail - head);
+  parse_text_internal(handler, context, head, tail - head, FALSE);
 
   if (handler->endElement != NULL)
     (*handler->endElement)(context, "a");
