@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_jbbs.c,v 1.38.2.1 2004/05/01 15:45:34 fuyu Exp $
+ * $Id: ochusha_thread_jbbs.c,v 1.38.2.3 2004/12/29 06:58:28 fuyu Exp $
  */
 
 #include "config.h"
@@ -54,17 +54,15 @@
 # include <oniguruma.h>
 #endif
 
-#if (ONIGURUMA_VERSION_MAJOR >= 2) && (ONIGURUMA_VERSION_MINOR > 0)
-# define ONIGURUMA_2_2_API		1
+#if (ONIGURUMA_VERSION_MAJOR < 2) || (ONIGURUMA_VERSION_MINOR < 2)
+#error "Please use included oniguruma, we no longer support oniguruma prior to 2.2"
 #endif
 
-#define ENABLE_HTML_TO_DAT_CONVERTER	1
 
+#define DEBUG_DAT			0
+#define DEBUG_DAT_MOST			0
 
-#define DEBUG_DAT	0
-#define DEBUG_DAT_MOST	0
-
-#define ANALYSIS_INTERVAL	100
+#define ANALYSIS_INTERVAL		100
 
 
 static void ochusha_thread_jbbs_class_init(OchushaThreadJBBSClass *klass);
@@ -942,6 +940,8 @@ ochusha_thread_jbbs_post_supported(OchushaBBSThread *thread)
   switch (thread->board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_MACHIBBS:
+    case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
+    case OCHUSHA_BBS_TYPE_MITINOKU:
       return TRUE;
 
     default:
@@ -963,7 +963,7 @@ ochusha_thread_jbbs_make_post_response_message(OchushaThread2ch *thread_2ch,
    * ԤˡʤΤǡ褺longѴƤޤ
    * long32bitʥƥˤ2038ǯ()¸ߤ롣
    */
-  long long_time = time;
+  long long_time = (long)time;
   OchushaBBSThread *thread = OCHUSHA_BBS_THREAD(thread_2ch);
 
   switch (thread->board->bbs_type)
@@ -971,6 +971,27 @@ ochusha_thread_jbbs_make_post_response_message(OchushaThread2ch *thread_2ch,
     case OCHUSHA_BBS_TYPE_MACHIBBS:
       return g_strdup_printf("submit=%%8F%%91%%82%%AB%%8D%%9E%%82%%DE&NAME=%s&MAIL=%s&MESSAGE=%s&BBS=%s&KEY=%s&TIME=%ld", from, mail, message, bbs, key, long_time);
 
+    case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
+      {
+	const char *base_path
+	  = ochusha_bulletin_board_get_base_path(thread->board);
+	char *dir;
+	char *body;
+	char *tmp_pos;
+	g_return_val_if_fail(base_path != NULL && *base_path == '/', NULL);
+
+	dir = G_STRDUP(base_path + 1);
+	tmp_pos = strrchr(dir, '/');
+	if (tmp_pos != NULL)
+	  *tmp_pos = '\0';
+	body = g_strdup_printf("submit=%%BD%%F1%%A4%%AD%%B9%%FE%%A7%%E0&NAME=%s&MAIL=%s&MESSAGE=%s&BBS=%s&KEY=%s&TIME=%ld&DIR=%s", from, mail, message, bbs, key, long_time, dir);
+	G_FREE(dir);
+	return body;
+      }
+
+    case OCHUSHA_BBS_TYPE_MITINOKU:
+      return g_strdup_printf("submit=%%BD%%F1%%A4%%AD%%B9%%FE%%A7%%E0&name=%s&mail=%s&mode=thread&comment=%s&bbs=%s&key=%s&time=%ld", from, mail, message, bbs, key, long_time);
+
     default:
       return NULL;	/* ̤ݡ */
     }
@@ -1007,42 +1028,38 @@ static void
 initialize_default_regexp_patterns(void)
 {
   title_pattern_string = "<title>(.*)</title>";
-  title_pattern_end
-    = title_pattern_string + strlen(title_pattern_string);
+  title_pattern_end = title_pattern_string + strlen(title_pattern_string);
 
-  /* "\314\276\301\260\241\247" == "̾" in EUC-JP */
-  /* "\305\352\271\306\306\374\241\247" == "" in EUC-JP */
-#if 0
-  jbbs_shitaraba_response_pattern_string = "<[dD][tT]>([1-9][0-9]*) \314\276\301\260\241\247[^<]*(<[fF][oO][nN][tT][^>]*|<[aA][^>]*)>(.*)\305\352\271\306\306\374\241\247 ([^<]*)<[bB][rR]><[dD][dD]>(.*)<[bB][rR]><[bB][rR]>$";
-#else
-  /* ʤ"̾"ѥˤȥޥåʤġġ*/
-  jbbs_shitaraba_response_pattern_string = "<[dD][tT]>([1-9][0-9]*) [^<]*(<[fF][oO][nN][tT][^>]*|<[aA][^>]*)>(.*)\305\352\271\306\306\374\241\247 ([^<]*)<[bB][rR]><[dD][dD]>(.*)<[bB][rR]><[bB][rR]>$";
-#endif
+#define NAME_EUCJP	"\314\276\301\260\241\247"	   /* "̾" */
+#define DATE_EUCJP	"\305\352\271\306\306\374\241\247" /* "" */
+
+  jbbs_shitaraba_response_pattern_string
+    = "(?i:<dt><a href[^>]*>)([1-9][0-9]*)(?i:</a>) " NAME_EUCJP
+      "[^<]*(<(?i:font)[^>]*|<(?i:a)[^>]*)>(.*)" DATE_EUCJP
+      " (.*)(?i:<br><dd>)(.*)(?i:<br><br>)$";
   jbbs_shitaraba_response_pattern_end
     = (jbbs_shitaraba_response_pattern_string
        + strlen(jbbs_shitaraba_response_pattern_string));
 
-  /* "\226\274\221\117\201\106" == "̾" in Shift_JIS */
-  /* "\223\212\215\145\223\372\201\106" == "" in Shift_JIS */
-#if 0
-  machibbs_response_pattern_string = "<[dD][tT]>([1-9][0-9]*) \226\274\221\117\201\106[^<]*(<[fF][oO][nN][tT][^>]*|<[aA][^>]*)>(.*)\223\212\215\145\223\372\201\106 (.*)<[bB][rR]><[dD][dD]>(.*)<[bB][rR]><[bB][rR]>$";
-#else
-  machibbs_response_pattern_string = "<[dD][tT]>([1-9][0-9]*) [^<]*(<[fF][oO][nN][tT][^>]*|<[aA][^>]*)>(.*)\223\212\215\145\223\372\201\106 (.*)<[bB][rR]><[dD][dD]>(.*)<[bB][rR]><[bB][rR]>$";
-#endif
-  machibbs_response_pattern_end
-    = (machibbs_response_pattern_string
-       + strlen(machibbs_response_pattern_string));
-
-  /* "\314\276\301\260\241\247" == "̾" in EUC-JP */
-  /* "\305\352\271\306\306\374\241\247" == "" in EUC-JP */
-#if 0
-  mitinoku_response_pattern_string = "<[dD][tT]>([1-9][0-9]*) \314\276\301\260\241\247[^<]*(<[fF][oO][nN][tT][^>]*|<[aA][^>]*)>(.*)\305\352\271\306\306\374\241\247(.*)<[dD][dD]>(.*)<[bB][rR]><[bB][rR]>$";
-#else
-  mitinoku_response_pattern_string = "<[dD][tT]>([1-9][0-9]*) [^<]*(<[fF][oO][nN][tT][^>]*|<[aA][^>]*)>(.*)\305\352\271\306\306\374\241\247(.*)<[dD][dD]>(.*)<[bB][rR]><[bB][rR]>$";
-#endif
+  mitinoku_response_pattern_string
+    = "(?i:<dt>)([1-9][0-9]*) " NAME_EUCJP
+      "[^<]*(<(?i:font)[^>]*|<(?i:a)[^>]*)>(.*)" DATE_EUCJP
+      "(.*)(?i:<dd>)(.*)(?i:<br><br>)$";
   mitinoku_response_pattern_end
     = (mitinoku_response_pattern_string
        + strlen(mitinoku_response_pattern_string));
+
+
+#define NAME_SJIS	"\226\274\221\117\201\106"	   /* "̾" */
+#define DATE_SJIS	"\223\212\215\145\223\372\201\106" /* "" */
+
+  machibbs_response_pattern_string
+    = "(?i:<dt>)([1-9][0-9]*) " NAME_SJIS
+      "[^<]*(<(?i:font)[^>]*|<(?i:a)[^>]*)>(.*)" DATE_SJIS
+      " (.*)(?i:<br><dd>)(.*)(?i:<br><br>)$";
+  machibbs_response_pattern_end
+    = (machibbs_response_pattern_string
+       + strlen(machibbs_response_pattern_string));
 }
 
 
@@ -1061,11 +1078,7 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
   gboolean dump_html = FALSE;
   regex_t *title_pattern = NULL;
   regex_t *response_pattern = NULL;
-#ifdef ONIGURUMA_2_2_API
   OnigRegion *match_region = NULL;
-#else
-  RegRegion *match_region = NULL;
-#endif
 
   if (title_pattern_string == NULL)
     initialize_default_regexp_patterns();
@@ -1073,42 +1086,19 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
   switch (thread->board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
-#ifdef ONIGURUMA_2_2_API
       if (onig_new(&title_pattern,
 		   (char *)title_pattern_string, (char *)title_pattern_end,
-		   ONIG_OPTION_EXTEND, ONIG_ENCODING_EUC_JP,
-		   ONIG_SYNTAX_POSIX_EXTENDED, NULL) != ONIG_NORMAL)
-#else
-      if (regex_new(&title_pattern,
-		    (char *)title_pattern_string, (char *)title_pattern_end,
-# ifdef REG_ENCODING_EUC_JP
-		    REG_OPTION_EXTEND, REG_ENCODING_EUC_JP,
-# else /* old style */
-		    REG_OPTION_EXTEND, REGCODE_EUCJP,
-# endif
-		    REG_SYNTAX_POSIX_EXTENDED, NULL) != REG_NORMAL)
-#endif
+		   ONIG_OPTION_NONE, ONIG_ENCODING_EUC_JP,
+		   ONIG_SYNTAX_RUBY, NULL) != ONIG_NORMAL)
 	{
 	  fprintf(stderr, "invalid regular expression\n");
 	  goto terminated;
 	}
-#ifdef ONIGURUMA_2_2_API
       if (onig_new(&response_pattern,
 		   (char *)jbbs_shitaraba_response_pattern_string,
 		   (char *)jbbs_shitaraba_response_pattern_end,
-		   ONIG_OPTION_EXTEND, ONIG_ENCODING_EUC_JP,
-		   ONIG_SYNTAX_POSIX_EXTENDED, NULL) != ONIG_NORMAL)
-#else
-      if (regex_new(&response_pattern,
-		    (char *)jbbs_shitaraba_response_pattern_string,
-		    (char *)jbbs_shitaraba_response_pattern_end,
-# ifdef REG_ENCODING_EUC_JP
-		    REG_OPTION_EXTEND, REG_ENCODING_EUC_JP,
-# else /* old style */
-		    REG_OPTION_EXTEND, REGCODE_EUCJP,
-# endif
-		    REG_SYNTAX_POSIX_EXTENDED, NULL) != REG_NORMAL)
-#endif
+		   ONIG_OPTION_NONE, ONIG_ENCODING_EUC_JP,
+		   ONIG_SYNTAX_RUBY, NULL) != ONIG_NORMAL)
 	{
 	  fprintf(stderr, "invalid regular expression\n");
 	  goto terminated;
@@ -1121,42 +1111,19 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
       break;
 
     case OCHUSHA_BBS_TYPE_MACHIBBS:
-#ifdef ONIGURUMA_2_2_API
       if (onig_new(&title_pattern,
 		   (char *)title_pattern_string, (char *)title_pattern_end,
-		   ONIG_OPTION_EXTEND, ONIG_ENCODING_SJIS,
-		   ONIG_SYNTAX_POSIX_EXTENDED, NULL) != ONIG_NORMAL)
-#else
-      if (regex_new(&title_pattern,
-		    (char *)title_pattern_string, (char *)title_pattern_end,
-# ifdef REG_ENCODING_SJIS
-		    REG_OPTION_EXTEND, REG_ENCODING_SJIS,
-# else /* old style */
-		    REG_OPTION_EXTEND, REGCODE_SJIS,
-# endif
-		    REG_SYNTAX_POSIX_EXTENDED, NULL) != REG_NORMAL)
-#endif
+		   ONIG_OPTION_NONE, ONIG_ENCODING_SJIS,
+		   ONIG_SYNTAX_RUBY, NULL) != ONIG_NORMAL)
 	{
 	  fprintf(stderr, "invalid regular expression\n");
 	  goto terminated;
 	}
-#ifdef ONIGURUMA_2_2_API
       if (onig_new(&response_pattern,
 		   (char *)machibbs_response_pattern_string,
 		   (char *)machibbs_response_pattern_end,
-		   ONIG_OPTION_EXTEND, ONIG_ENCODING_SJIS,
-		   ONIG_SYNTAX_POSIX_EXTENDED, NULL) != ONIG_NORMAL)
-#else
-      if (regex_new(&response_pattern,
-		    (char *)machibbs_response_pattern_string,
-		    (char *)machibbs_response_pattern_end,
-# ifdef REG_ENCODING_SJIS
-		    REG_OPTION_EXTEND, REG_ENCODING_SJIS,
-# else /* old style */
-		    REG_OPTION_EXTEND, REGCODE_SJIS,
-# endif
-		    REG_SYNTAX_POSIX_EXTENDED, NULL) != REG_NORMAL)
-#endif
+		   ONIG_OPTION_NONE, ONIG_ENCODING_SJIS,
+		   ONIG_SYNTAX_RUBY, NULL) != ONIG_NORMAL)
 	{
 	  fprintf(stderr, "invalid regular expression\n");
 	  goto terminated;
@@ -1169,42 +1136,19 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
       break;
 
     case OCHUSHA_BBS_TYPE_MITINOKU:
-#ifdef ONIGURUMA_2_2_API
       if (onig_new(&title_pattern,
 		   (char *)title_pattern_string, (char *)title_pattern_end,
-		   ONIG_OPTION_EXTEND, ONIG_ENCODING_EUC_JP,
-		   ONIG_SYNTAX_POSIX_EXTENDED, NULL) != ONIG_NORMAL)
-#else
-      if (regex_new(&title_pattern,
-		    (char *)title_pattern_string, (char *)title_pattern_end,
-# ifdef REG_ENCODING_EUC_JP
-		    REG_OPTION_EXTEND, REG_ENCODING_EUC_JP,
-# else /* old style */
-		    REG_OPTION_EXTEND, REGCODE_EUCJP,
-# endif
-		    REG_SYNTAX_POSIX_EXTENDED, NULL) != REG_NORMAL)
-#endif
+		   ONIG_OPTION_NONE, ONIG_ENCODING_EUC_JP,
+		   ONIG_SYNTAX_RUBY, NULL) != ONIG_NORMAL)
 	{
 	  fprintf(stderr, "invalid regular expression\n");
 	  goto terminated;
 	}
-#ifdef ONIGURUMA_2_2_API
       if (onig_new(&response_pattern,
 		   (char *)mitinoku_response_pattern_string,
 		   (char *)mitinoku_response_pattern_end,
-		   ONIG_OPTION_EXTEND, ONIG_ENCODING_EUC_JP,
-		   ONIG_SYNTAX_POSIX_EXTENDED, NULL) != ONIG_NORMAL)
-#else
-      if (regex_new(&response_pattern,
-		    (char *)mitinoku_response_pattern_string,
-		    (char *)mitinoku_response_pattern_end,
-# ifdef REG_ENCODING_EUC_JP
-		    REG_OPTION_EXTEND, REG_ENCODING_EUC_JP,
-# else /* old style */
-		    REG_OPTION_EXTEND, REGCODE_EUCJP,
-# endif
-		    REG_SYNTAX_POSIX_EXTENDED, NULL) != REG_NORMAL)
-#endif
+		   ONIG_OPTION_NONE, ONIG_ENCODING_EUC_JP,
+		   ONIG_SYNTAX_RUBY, NULL) != ONIG_NORMAL)
 	{
 	  fprintf(stderr, "invalid regular expression\n");
 	  goto terminated;
@@ -1254,11 +1198,7 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
 
   g_assert(title_pattern != NULL);
   g_assert(response_pattern != NULL);
-#ifdef ONIGURUMA_2_2_API
   match_region = onig_region_new();
-#else
-  match_region = regex_region_new();
-#endif
 
   ochusha_async_buffer_lock(html_buffer);
   while (TRUE)
@@ -1298,23 +1238,12 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
 	  fprintf(stderr, "html_line: \"%s\"\n", html_line_buffer);
 #endif
 
-#ifdef ONIGURUMA_2_2_API
 	  onig_region_clear(match_region);
-#else
-	  regex_region_clear(match_region);
-#endif
 	  if (response_number == 1 && title == NULL
-#ifdef ONIGURUMA_2_2_API
 	      && onig_search(title_pattern,
 			     html_line_buffer, html_line_buffer_tail,
 			     html_line_buffer, html_line_buffer_tail,
 			     match_region, 0) >= 0)
-#else
-	      && regex_search(title_pattern,
-			      html_line_buffer, html_line_buffer_tail,
-			      html_line_buffer, html_line_buffer_tail,
-			      match_region, 0) >= 0)
-#endif
 	    {
 	      char *title_head = html_line_buffer + match_region->beg[1];
 	      int title_len = match_region->end[1] - match_region->beg[1];
@@ -1327,17 +1256,10 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
 	    {
 	      fprintf(stderr, "html_line: \"%s\"\n", html_line_buffer);
 	    }
-#ifdef ONIGURUMA_2_2_API
 	  else if (onig_search(response_pattern,
 			       html_line_buffer, html_line_buffer_tail,
 			       html_line_buffer, html_line_buffer_tail,
 			       match_region, 0) >= 0)
-#else
-	  else if (regex_search(response_pattern,
-				html_line_buffer, html_line_buffer_tail,
-				html_line_buffer, html_line_buffer_tail,
-				match_region, 0) >= 0)
-#endif
 	    {
 	      int res_num;
 	      char *tag_head = html_line_buffer + match_region->beg[2];
@@ -1372,6 +1294,24 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
 			    mailto_len = mailto_tail - mailto_head;
 			}
 		    }
+		  else
+		    {
+		      mailto_head = g_strstr_len(tag_head + 2, tag_rest,
+						 "href=mailto:");
+		      if (mailto_head != NULL)
+			{
+			  mailto_head += 12;	/* "href=mailto:"Ф */
+			  tag_rest -= 12;
+			  if (tag_rest > 0)
+			    {
+			      const char *mailto_tail
+				= mempbrk(mailto_head, " >\t\n\r", tag_rest);
+			      if (mailto_tail != NULL)
+				mailto_len = mailto_tail - mailto_head;
+			    }
+			}
+		    }
+
 		}
 
 	      sscanf(html_line_buffer + match_region->beg[1], "%d", &res_num);
@@ -1642,21 +1582,13 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
     }
 
  terminated:
-#ifdef ONIGURUMA_2_2_API
   if (title_pattern != NULL)
     onig_free(title_pattern);
   if (response_pattern != NULL)
     onig_free(response_pattern);
   if (match_region != NULL)
     onig_region_free(match_region, 1);
-#else
-  if (title_pattern != NULL)
-    regex_free(title_pattern);
-  if (response_pattern != NULL)
-    regex_free(response_pattern);
-  if (match_region != NULL)
-    regex_region_free(match_region, 1);
-#endif
+
   OCHU_OBJECT_UNREF(dat_buffer);
   OCHU_OBJECT_UNREF(args->broker);
 }
@@ -1766,7 +1698,6 @@ ochusha_thread_jbbs_fake_responses_source(OchushaThread2ch *thread_2ch,
     {
     case OCHUSHA_BBS_TYPE_JBBS:
     case OCHUSHA_BBS_TYPE_MACHIBBS:
-    case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
       if (snprintf(cgi_url, PATH_MAX, "%s?BBS=%s&KEY=%s&START=%d%s",
 		   ochusha_board_2ch_get_read_cgi_url(board_2ch),
 		   thread->board->id, thread->id,
@@ -1776,6 +1707,15 @@ ochusha_thread_jbbs_fake_responses_source(OchushaThread2ch *thread_2ch,
 	cgi_url[0] = '\0';
       break;
 
+    case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
+      if (snprintf(cgi_url, PATH_MAX, "http://%s/bbs/read.cgi%s%s/%s/%d-",
+		   ochusha_bulletin_board_get_server(thread->board),
+		   ochusha_bulletin_board_get_base_path(thread->board),
+		   ochusha_bulletin_board_get_id(thread->board),
+		   thread->id, number_of_cached_responses + 1) >= PATH_MAX)
+	cgi_url[0] = '\0';
+      break;
+
     case OCHUSHA_BBS_TYPE_MITINOKU:
       if (thread->number_of_responses_on_server <= number_of_cached_responses)
 	return dat_buffer;
