@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: utils.h,v 1.13.2.1 2004/05/24 10:03:40 fuyu Exp $
+ * $Id: utils.h,v 1.13.2.3 2004/12/29 06:59:08 fuyu Exp $
  */
 
 #ifndef _UTILS_H_
@@ -53,6 +53,8 @@ char *convert_string(iconv_t converter, iconv_helper *helper,
 		     const char *src, int length);
 size_t cp932_to_utf8_helper(const char **inbuf, size_t *inbytesleft,
 			    char **outbuf, size_t *outbytesleft);
+size_t eucjp_to_utf8_helper(const char **inbuf, size_t *inbytesleft,
+			    char **outbuf, size_t *outbytesleft);
 
 gchar *wipe_string(const gchar *string);
 
@@ -64,6 +66,8 @@ char *ochusha_utils_url_extract_http_absolute_path(const char *url);
 char *ochusha_utils_url_encode_string(const char *src);
 char *ochusha_utils_url_decode_string(const char *src);
 
+char *ochusha_utils_javascript_extract_url(const char *url);
+
 time_t ochusha_utils_get_utc_time(const char *date_string);
 
 const char *mempbrk(const char *string, const char *charset, size_t len);
